# Changelog
All notable changes to azure-devops-tools will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Added
<!-- new features. -->

### Changed 
<!-- for changes in existing functionality -->

### Deprecated 
<!-- soon-to-be removed features -->

### Removed 
<!-- now removed features -->

### Fixed
<!-- any bug fixes -->

### Security
<!-- vulnerabilities -->


## [0.0.0] - 1900-01-01
### Added
<!-- new features. -->

### Changed 
<!-- for changes in existing functionality -->

### Deprecated 
<!-- soon-to-be removed features -->

### Removed 
<!-- now removed features -->

### Fixed
<!-- any bug fixes -->

### Security
<!-- vulnerabilities -->

[Unreleased]: link/to/adopt-nightly
[0.0.0]: link/to/adopt-0.0.0

